abacusai.extracted_fields — AbacusAI documentation

# abacusai.extracted_fields

## Classes

`ExtractedFields` | The fields extracted from a document.

## Module Contents

class abacusai.extracted_fields.ExtractedFields(client, data=None, rawLlmResponse=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The fields extracted from a document.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (dict) – The data for the document.

    - rawLlmResponse (str) – The raw llm response. Only returned if it could not be parsed to json.

  data
  raw_llm_response
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict